from random import randrange
from currency_converter import CurrencyConverter
from .Game import Game


class CurrencyRouletteGame(Game):

    def __init__(self, difficulty):
        self.difficulty = difficulty
        self.rand_number = randrange(1, 101)

    def get_money_interval(self):
        c = CurrencyConverter()
        total_converted_cash = c.convert(self.rand_number, 'USD', 'ILS')
        min_interval = total_converted_cash - (5 - self.difficulty)
        max_interval = total_converted_cash + (5 - self.difficulty)

        return min_interval, max_interval

    def get_guess_from_user(self):
        print(f"Can you guess whats the conversion rate of ${self.rand_number}?")
        user_conversation_guess = input("Enter Guess: ")
        return int(user_conversation_guess)

    def play(self):
        user_conversation_guess = self.get_guess_from_user()
        min_interval, max_interval = self.get_money_interval()

        return max_interval >= user_conversation_guess >= min_interval



from .Helper_funcs import HelperFuncs
from .GuessGame import GuessGame
from .MemoryGame import MemoryGame
from .CurrencyRouletteGame import CurrencyRouletteGame


class Live():





    def welcome(self, name):
        print()
        print(f"Hello {name} and welcome to the world of Games(WoG).")
        print(f"Here you can find many cool games to play.")
        return ""

    def load_game(self):

        helper_fuc = HelperFuncs()

        print()
        print("Please choose a game to play:")
        print("1. Memory Game - a sequence of numbers will appear for 1 second and you have to guess it back")
        print("2. Guess Game - guess a number and see if you chose like the computer")
        print("3. Currency Roulette - try and guess the value of a random amount of USD in ILS")

        game_number = helper_fuc.input_int_validation("please choose a number between 1 and 3: ",1,3)


        if int(game_number) == 1:

            game_difficulty = helper_fuc.input_int_validation("Please choose game difficulty from 1 to 5: ",1,5)

            ins_memory_game = MemoryGame(int(game_difficulty))
            return ins_memory_game.play()


        elif int(game_number) == 2:

            game_difficulty = helper_fuc.input_int_validation("Please choose game difficulty from 1 to 5: ",1,5)

            ins_guess_game = GuessGame(int(game_difficulty))
            return ins_guess_game.play()

        elif int(game_number) == 3:

            game_difficulty = helper_fuc.input_int_validation("Please choose game difficulty from 1 to 5: ",1,5)

            ins_currency_game = CurrencyRouletteGame(int(game_difficulty))
            return ins_currency_game.play()






class HelperFuncs():


    def input_int_validation(self, message, low, high):

        input_data = input(message)

        while input_data.isalpha() or int(input_data) > int(high) or int(input_data) < int(low):
            print(message)
            input_data = input(message)

        return input_data


   


from random import randrange
from .Game import Game
from .Helper_funcs import HelperFuncs



class GuessGame(Game):

    def __init__(self,difficulty):
        self.difficulty = difficulty

    def generate_number(self):
        self.secret_number = randrange(1, self.difficulty + 1)


    def get_guess_from_user(self):

        helper_fuc = HelperFuncs()
        user_number = helper_fuc.input_int_validation(f"Please enter a number between 1 and {self.difficulty} : ",1,self.difficulty)

        return int(user_number)

    def compare_results(self):
        return self.get_guess_from_user() == self.secret_number

    def play(self):
        self.generate_number()
        return self.compare_results()



from random import randrange
from time import sleep
from subprocess import *
from .Game import Game
import os


class MemoryGame(Game):

    def __init__(self, difficulty):
        self.difficulty = difficulty


    def generate_sequence(self):

        list_of_nums = []
        for number in range(0,self.difficulty):

            list_of_nums.append(randrange(1,102))

        return list_of_nums


    def get_list_from_user(self):

        user_list = [int(x) for x in input(f"Please enter a size of {self.difficulty} list of numbers: ").split()]

        return user_list

    def is_list_equal(self):

        computer_list = self.generate_sequence()
        print(computer_list)
        sleep(0.7)

        if os.name == 'nt':
            run(["cls"],shell=True)
        else:
            run("clear")

        user_list = self.get_list_from_user()

        return set(computer_list) == set(user_list)

    def play(self):




       return self.is_list_equal()








from setuptools import setup
#from distutils.core import setup
setup(
  name = 'yonwog',
  packages = ['yonwog'],
  version = '0.0.1',
  license='yon',
  description = 'a python 3 games cli package project for school',
  author = 'Yonatan shani',
  author_email = 'sth@sth.com',
  keywords=['yonwog'],
  install_requires=[
          'validators',
          'beautifulsoup4',
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',
    'Intended Audience :: Developers',
    'Topic :: Software Development :: Build Tools',
    'Programming Language :: Python :: 3',
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
    'Programming Language :: Python :: 3.7',
    'Programming Language :: Python :: 3.8',
    'Programming Language :: Python :: 3.9',
  ],
)